ERC1155 class

Constructors

ERC1155(String contractAddress, String providerUrl, [String? signerPrivateKey])

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

balanceOf(String address, BigInt id) Future<BigInt>
balanceOfBatch(List<String> address, List<BigInt> ids) Future<List>
isApprovedForAll(String address, String operator) Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
safeBatchTransferFrom(String from, String to, List<BigInt> amounts, dynamic data) Future<TransactionResponse>
safeTransferFrom(String from, String to, BigInt id, BigInt amount, dynamic data) Future<TransactionResponse>
setApprovalForAll(String address, bool approved) Future<TransactionResponse>
supportsInterface(dynamic interfaceId) Future<bool>
toString() String
A string representation of this object.
inherited
uri(BigInt id) Future<String>

Operators

operator ==(Object other) bool
The equality operator.
inherited