ERC721 class

Constructors

ERC721(String contractAddress, String providerUrl, [String? signerPrivateKey])

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

approve(BigInt tokenId) Future<TransactionResponse>
balanceOf(String address) Future<BigInt>
isApprovedForAll(String owner, String operator) Future<bool>
mint(String recipient, BigInt amount) Future<TransactionResponse>
name() Future<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
ownerOf(BigInt tokenId) Future<String>
safeTransferFrom(String from, String to, BigInt tokenId, [dynamic data]) Future<TransactionResponse>
setApprovalForAll(String operator, bool approved) Future<TransactionResponse>
supportsInterface(dynamic interfaceId) Future<bool>
symbol() Future<String>
tokenURI(BigInt tokenId) Future<String>
toString() String
A string representation of this object.
inherited
totalSupply() Future<BigInt>
transferFrom(String from, String to, BigInt tokenId) Future<TransactionResponse>

Operators

operator ==(Object other) bool
The equality operator.
inherited