ERC1155Stake class

Constructors

ERC1155Stake(String contractAddress, String providerUrl, [String? signerPrivateKey])

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

claimRewards(BigInt tokenId) Future
contractType() Future
contractURI() Future
contractVersion() Future
depositRewardTokens(BigInt amount) Future
getDefaultRewardsPerUnitTime() Future
getDefaultTimeUnit() Future
getRewardsPerUnitTime() Future
getRewardTokenBalance() Future
getRoleAdmin(String role) Future
getRoleMember(String role, BigInt index) Future
getRoleMemberCount(String role) Future
getStakeInfo(String staker) Future
getStakeInfoForToken(BigInt tokenId, String staker) Future
getTimeUnit() Future
grantRole(String role, String account) Future
hasRole(String role, String account) Future
hasRoleWithSwitch(String role, String account) Future
indexedTokens(BigInt input) Future
isIndexed(BigInt input) Future
isTrustedForwarder(String forwarder) Future
multicall(List<String> data) Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onERC1155BatchReceived(String operator, String from, List<BigInt> ids, List<BigInt> values, String data) Future
onERC1155Received(String operator, String from, BigInt id, BigInt value, String data) Future
renounceRole(String role, String account) Future
revokeRole(String role, String account) Future
rewardToken() Future
setContractURI(String uri) Future
setDefaultRewardsPerUnitTime(BigInt defaultRewardsPerUnitTime) Future
setDefaultTimeUnit(BigInt defaultTimeUnit) Future
setRewardsPerUnitTime(BigInt tokenId, BigInt rewardsPerUnitTime) Future
setTimeUnit(BigInt timeUnit) Future
stake(BigInt amount) Future
stakers(BigInt input, String address) Future
stakersArray(BigInt input1, BigInt input2) Future
stakingToken() Future
supportsInterface(BigInt interfaceId) Future
toString() String
A string representation of this object.
inherited
withdraw(BigInt amount) Future
withdrawRewardTokens(BigInt amount) Future

Operators

operator ==(Object other) bool
The equality operator.
inherited