ERC20Stake class

Constructors

ERC20Stake(String contractAddress, String providerUrl, [String? signerPrivateKey])

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

claimRewards() Future
contractType() Future
contractURI() Future
contractVersion() Future
depositRewardTokens(BigInt amount) Future
getRewardRatio() Future
getRewardTokenBalance() Future
getRoleAdmin(String role) Future
getRoleMember(String role, BigInt index) Future
getRoleMemberCount(String role) Future
getStakeInfo(String staker) Future
getTimeUnit() Future
grantRole(String role, String account) Future
hasRole(String role, String account) Future
hasRoleWithSwitch(String role, String account) Future
isTrustedForwarder(String forwarder) Future
multicall(List<String> data) Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
renounceRole(String role, String account) Future
revokeRole(String role, String account) Future
rewardToken() Future
rewardTokenDecimals() Future
setContractURI(String uri) Future
setRewardRatio(BigInt numerator, BigInt denominator) Future
setTimeUnit(BigInt timeUnit) Future
stake(BigInt amount) Future
stakers(String address) Future
stakersArray(BigInt input) Future
stakingToken() Future
stakingTokenBalance() Future
stakingTokenDecimals() Future
toString() String
A string representation of this object.
inherited
withdraw(BigInt amount) Future
withdrawRewardTokens(BigInt amount) Future

Operators

operator ==(Object other) bool
The equality operator.
inherited