OctacoreSmartAccountFactory class

Inheritance

Constructors

OctacoreSmartAccountFactory({dynamic rpcURL, dynamic signer})

Properties

contract ↔ Contract
getter/setter pairinherited
contractABI String
getter/setter pairinherited
contractAddress String
getter/setter pairinherited
contractName String
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
rpcURL String
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signer ↔ Signer<_SignerImpl>
getter/setter pairinherited

Methods

getAddress(String address, int salt) Future<String>
inherited
getByteCode(String address) Future<Uint8List>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited