SmartAccountFactory class
- Implementers
Constructors
- SmartAccountFactory({required dynamic contractAddress, required dynamic contractABI, required dynamic contractName, required dynamic rpcURL, required dynamic signer})
Properties
- contract ↔ Contract
-
getter/setter pair
- contractABI ↔ String
-
getter/setter pair
- contractAddress ↔ String
-
getter/setter pair
- contractName ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- rpcURL ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
signer
↔ Signer<
_SignerImpl> -
getter/setter pair
Methods
-
getAddress(
String address, int salt) → Future< String> -
getByteCode(
String address) → Future< Uint8List> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- entryPoint → const String