SmartWallet class

Implementers

Constructors

SmartWallet({required String abi, required String scwAddress, required String rpcURL, dynamic provider, required bool isInitialized, required String ownerAddress, required int salt, required String bundlerURL, required String factoryAddress, required Signer<_SignerImpl> signer})

Properties

abi String
getter/setter pair
bundlerURL String
getter/setter pair
contract ↔ Contract
getter/setter pair
deployedContract ↔ DeployedContract
getter/setter pair
entryPointContract EntryPoint
getter/setter pair
factoryAddress String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
initCode String
getter/setter pair
isInitialized bool
getter/setter pair
isVerified bool
getter/setter pair
ownerAddress String
getter/setter pair
rpcURL String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
salt int
getter/setter pair
signer ↔ Signer<_SignerImpl>
getter/setter pair

Methods

addDeposit({required BigInt value, required Credentials credentials, BigInt? gasPrice, BigInt? gasLimit}) Future
callContract({required String contractAddress, required String contractAbi, required String functionName, required List args, required bool usePaymaster, BigInt? gasPrice, BigInt? gasLimit}) Future<RPCResult>
callContractDirect({required String contractAddress, required String contractAbi, required String functionName, required List args, required bool usePaymaster, required String currentAddress, BigInt? gasPrice, BigInt? gasLimit}) Future<String>
concatenateBuffers(List<Uint8List> buffers) Uint8List
constructPaymasterAndData(String paymasterAddress, String z, String signedPayMasterData) Uint8List
depositToWallet({required BigInt value}) Future<void>
encodeParameters(List<String> types, List values) String
execute({required String to, required BigInt value, required List<int> data, BigInt? gasPrice, BigInt? gasLimit}) Future<TransactionResponse?>
fetchPersonalSignature(String message, String currentAddress) Future<String>
getBalance() Future
getDeposit() Future
getEntryPoint() Future<String>
getNonce() Future<BigInt>
getOwner() Future<String>
getUserOpEncodedData({required String contractAddress, required String contractAbi, required String functionName, required List args, BigInt? gasPrice, BigInt? gasLimit}) Future<String>
getUserOpTransactionHash(UserOperationResult? userOpHash) Future<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendSignedOp(String signature, UserOperation userOp) Future<String>
toString() String
A string representation of this object.
inherited
transfer(String toAddress, String value, String data, bool usePaymaster) Future<RPCResult>
withdrawDepositTo({required String to, required BigInt value, required Credentials credentials, BigInt? gasPrice, BigInt? gasLimit}) Future<TransactionResponse?>

Operators

operator ==(Object other) bool
The equality operator.
inherited