VerifyingPaymaster class

Inheritance

Constructors

VerifyingPaymaster({required String contractAddress, required Signer<_SignerImpl> signer})

Properties

abi String
getter/setter pairinherited
contract ↔ Contract
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signer ↔ Signer<_SignerImpl>
getter/setter pairinherited

Methods

getHash({required dynamic userOp, required int validUntil, required int validAfter}) Future<String>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited