RPCModel class
Constructors
- RPCModel({UserOperationHashResult? userOperationHashResult, UserOperationResult? userOperationResult, String? id, String? jsonrpc, RPCError? error})
-
RPCModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
- error → RPCError?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
final
- jsonrpc → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userOperationHashResult → UserOperationHashResult?
-
final
- userOperationResult → UserOperationResult?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited