Vote class

Constructors

Vote(String contractAddress, String providerUrl, [String? signerPrivateKey])

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

BALLOT_TYPEHASH() Future
castVote(BigInt proposalId, int support) Future
castVoteBySig(BigInt proposalId, int support, int v, String r, String s) Future
castVoteWithReason(BigInt proposalId, int support, String reason) Future
castVoteWithReasonAndParams(BigInt proposalId, int support, String reason, String params) Future
castVoteWithReasonAndParamsBySig(BigInt proposalId, int support, String reason, String params, int v, String r, String s) Future
contractType() Future
contractURI() Future
contractVersion() Future
COUNTING_MODE() Future
execute(List<String> targets, List<BigInt> values, List<String> calldatas, String descriptionHash) Future
EXTENDED_BALLOT_TYPEHASH() Future
getAllProposals() Future
getVotes(String account, BigInt blockNumber) Future
getVotesWithParams(String account, BigInt blockNumber, String params) Future
hasProposal(List<String> targets, List<BigInt> values, List<String> calldatas, String descriptionHash) Future
hasVoted(BigInt proposalId, String account) Future
isTrustedForwarder(String forwarder) Future
name() Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onERC1155BatchReceived(String operator, String from, List<BigInt> ids, List<BigInt> values, String data) Future
onERC1155Received(String operator, String from, BigInt id, BigInt value, String data) Future
onERC721Received(String operator, String from, BigInt value, String data) Future
proposalDeadline(BigInt proposalId) Future
proposalIndex() Future
proposals(BigInt input) Future
proposalSnapshot(BigInt proposalId) Future
proposalThreshold() Future
proposalVotes(BigInt proposalId) Future
propose(List<String> targets, List<BigInt> values, List<String> calldatas, String description) Future
quorum(BigInt blockNumber) Future
quorumDenominator() Future
quorumNumerator([BigInt? blockNumber]) Future
relay(String target, BigInt value, String data) Future
setContractURI(String uri) Future
setProposalThreshold(BigInt newProposalThreshold) Future
setVotingDelay(BigInt newVotingDelay) Future
setVotingPeriod(BigInt newVotingPeriod) Future
state(BigInt proposalId) Future
supportsInterface(String interfaceId) Future
token() Future
toString() String
A string representation of this object.
inherited
updateQuorumNumerator(BigInt newQuorumNumerator) Future
version() Future
votingDelay() Future
votingPeriod() Future

Operators

operator ==(Object other) bool
The equality operator.
inherited