ERC20 class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
allowance(
String owner, String spender) → Future< BigInt> -
approve(
String spender, BigInt amount) → Future< TransactionResponse> -
balanceOf(
String address) → Future< BigInt> -
decimals(
) → Future< int> -
mint(
String recipient, BigInt amount) → Future< TransactionResponse> -
name(
) → Future< String> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
symbol(
) → Future< String> -
toString(
) → String -
A string representation of this object.
inherited
-
totalSupply(
) → Future< BigInt> -
transfer(
String recipient, BigInt amount) → Future< TransactionResponse> -
transferFrom(
String sender, String recipient, BigInt amount) → Future< TransactionResponse>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited